@@ -1,6 +1,7 @@
-from .data_set import *
-from .data_handler import *
+from .mnist import *
+from .data_2d import *
 from .classification import *
 from .storage import *
 from .initialization import *
 from .traversal import *
+from .darknet import *
